// java wrapper for vtkVRMLImporter object
//

package vtk;
import vtk.*;

public class vtkVRMLImporter extends vtkImporter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetShapeResolution_4(int id0);
  public void SetShapeResolution(int id0)
    { SetShapeResolution_4(id0); }

  private native int GetShapeResolution_5();
  public int GetShapeResolution()
    { return GetShapeResolution_5(); }

  private native long GetVRMLDEFObject_6(String id0);
  public vtkObject GetVRMLDEFObject(String id0) {
    long temp = GetVRMLDEFObject_6(id0);

    if (temp == 0) return null;
    return (vtkObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkVRMLImporter() { super(); }

  public vtkVRMLImporter(long id) { super(id); }
  public native long   VTKInit();

}
